reagent.impl.template


*current-default-compiler*cljs

source

adapt-react-classcljs

(adapt-react-class c)
source

as-elementcljs

(as-element this x fn-to-element)
source

cache-getcljs

(cache-get o k)
source

cached-custom-prop-namecljs

(cached-custom-prop-name k)
source

cached-parsecljs

(cached-parse this x _)
source

cached-prop-namecljs

(cached-prop-name k)
source

class-compilercljs

source

convert-custom-prop-valuecljs

(convert-custom-prop-value x)
source

convert-prop-valuecljs

(convert-prop-value x)
source

convert-propscljs

(convert-props props id-class)
source

create-compilercljs

(create-compiler opts)
source

custom-kv-convcljs

(custom-kv-conv o k v)
source

custom-prop-name-cachecljs

source

defc-elementcljs

(defc-element tag v)

Tag is a React function component already wrapped with Reagent function component implementation. This function just needs to wrap the Hiccup element children into the React element properties and set up the optional React key if set.

Tag is a React function component already wrapped
with Reagent function component implementation. This function just
needs to wrap the Hiccup element children into the React element
properties and set up the optional React key if set.
sourceraw docstring

expand-seqcljs

(expand-seq s compiler)
source

expand-seq-checkcljs

(expand-seq-check x compiler)
source

expand-seq-devcljs

(expand-seq-dev s o compiler)
source

fragment-elementcljs

(fragment-element argv compiler)
source

function-elementcljs

(function-element tag v first-arg compiler)
source

hiccup-elementcljs

(hiccup-element v compiler)
source

hiccup-tag?cljs

(hiccup-tag? x)
source

kv-convcljs

(kv-conv o k v)
source

make-elementcljs

(make-element this argv component jsprops first-child)
source

maybe-function-elementcljs

(maybe-function-element tag v compiler)

If given tag is a Class, use it as a class, else wrap in Reagent function wrapper.

If given tag is a Class, use it as a class,
else wrap in Reagent function wrapper.
sourceraw docstring

native-elementcljs

(native-element parsed argv first compiler)
source

parse-tagcljs

(parse-tag hiccup-tag)
source

prop-name-cachecljs

source

raw-elementcljs

(raw-element comp argv compiler)
source

re-tagcljs

Regular expression that parses a CSS-style id and class from a tag name.

Regular expression that parses a CSS-style id and class
from a tag name.
sourceraw docstring

reag-elementcljs

(reag-element tag v compiler)
source

reagent-fn-component?cljs

(reagent-fn-component? x)
source

set-default-compiler!cljs

(set-default-compiler! compiler)
source

set-id-classcljs

(set-id-class props id-class)

Takes the id and class from tag keyword, and adds them to the other props. Parsed tag is JS object with :id and :class properties.

Takes the id and class from tag keyword, and adds them to the
other props. Parsed tag is JS object with :id and :class properties.
sourceraw docstring

tag-name-cachecljs

source

valid-tag?cljs

(valid-tag? x)
source

vec-to-elemcljs

(vec-to-elem v compiler fn-to-element)
source

cljdoc builds & hosts documentation for Clojure/Script libraries