(defc-element tag v)Tag is a React function component already wrapped with Reagent function component implementation. This function just needs to wrap the Hiccup element children into the React element properties and set up the optional React key if set.
Tag is a React function component already wrapped with Reagent function component implementation. This function just needs to wrap the Hiccup element children into the React element properties and set up the optional React key if set.
(maybe-function-element tag v compiler)If given tag is a Class, use it as a class, else wrap in Reagent function wrapper.
If given tag is a Class, use it as a class, else wrap in Reagent function wrapper.
Regular expression that parses a CSS-style id and class from a tag name.
Regular expression that parses a CSS-style id and class from a tag name.
(set-id-class props id-class)Takes the id and class from tag keyword, and adds them to the other props. Parsed tag is JS object with :id and :class properties.
Takes the id and class from tag keyword, and adds them to the other props. Parsed tag is JS object with :id and :class properties.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |